@@ -26,6 +26,11 @@ class Synth:
         pass
     def play_track(self, track):
         print "FakeSynth.play_track(%s)" % track
+        last = None
         for e in track.m_v:
-            print e
+            if e[0] != last:
+                print
+            print e,
+            last = e[0]
+        print
 
