@@ -272,16 +272,23 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
             self.g_notebook.append_page(vbox, gtk.Label(_("Practise")))
             self.g_notebook.append_page(self.config_box, gtk.Label(_("Config")))
             self.g_notebook.show()
-        self.m_exercise_menu = []
+        self.g_cancel_test = gtk.Button(_("_Cancel test"))
+        self.g_cancel_test.connect('clicked', self.on_cancel_test)
+        self.action_area.pack_end(self.g_cancel_test, False)
+    def on_cancel_test(self, *w):
+        self.g_cancel_test.hide()
+        self.on_end_practise()
+        self.g_win.exit_test_mode()
     def do_test_complete(self):
         self.on_end_practise()
         req = self.m_t.m_P.get_test_requirement()
         res = self.m_t.m_statistics.get()
         if res >= req:
-            self.g_win.dialog_ok(_("Test completed!\nYour score was %.1f%%.\nThe test requirement was %.1f%%." % (res * 100, req * 100)))
+            self.g_win.dialog_ok(_("Test completed!\nYour score was %.1f%%.\nThe test requirement was %.1f%%.") % (res * 100, req * 100))
             self.m_t.m_statistics.store_test_passed()
         else:
-            self.g_win.dialog_ok(_("Test failed.\nYour score was %.1f%%.\nThe test requirement was %.1f%%." % (res * 100, req * 100)))
+            self.g_win.dialog_ok(_("Test failed.\nYour score was %.1f%%.\nThe test requirement was %.1f%%.") % (res * 100, req * 100))
+        self.g_cancel_test.hide()
         self.g_win.exit_test_mode()
     def set_lesson_heading(self, txt):
         self.g_lesson_heading.set_text('<span size="large"><b>%s</b></span>' % txt)
@@ -436,6 +443,11 @@ class LessonbasedGui(Gui):
         response = dlg.run()
         if response == gtk.RESPONSE_OK:
             self.m_t.m_P.header.random_transpose = dlg.get_value()
-            self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
+            if self.m_t.m_P.header.random_transpose == True:
+                self.g_random_transpose.set_text(_("Yes"))
+            elif self.m_t.m_P.header.random_transpose == False:
+                self.g_random_transpose.set_text(_("No"))
+            else:
+                self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
         dlg.destroy()
 
