@@ -277,7 +277,10 @@ class Gui(abstract.LessonbasedGui):
                 return
     def on_left_click(self, button):
         if self.m_t.q_status == const.QSTATUS_NO:
-            self.g_flashbar.flash(_("Click 'New' to begin."))
+            if self.m_t.m_app.m_test_mode:
+                self.g_flashbar.flash(_("Click 'Start test' to begin."))
+            else:
+                self.g_flashbar.flash(_("Click 'New' to begin."))
             return
         if self.m_t.q_status == const.QSTATUS_SOLVED:
             if self.m_t.guess_answer(button.get_data('cname')):
