@@ -685,7 +685,7 @@ class Window(gtk.Window):
         if i:
             i = i[0]
             iter = self.g_topics_liststore.iter_nth_child(None, i)
-            if self.m_app.m_ui.dialog_yesno(_("Delete topic '%s'") % self.m_tree.m_topics[i]['name']):
+            if self.m_app.m_ui.dialog_yesno(_("Delete topic '%s'?") % self.m_tree.m_topics[i]['name']):
                 self.m_tree.delete_topic(i)
                 self.update_gui()
                 self.g_add_lesson.set_sensitive(False)
