@@ -21,74 +21,6 @@ import gtk
 import cfg
 import gu
 
-class HarmonicProgressionLabel(gtk.HBox):
-    """
-    This class can parse strings like I-(6,4)V(5,3)-I and can be used
-    as button labels.
-    """
-    def __init__(self, str, align=''):
-        gtk.HBox.__init__(self)
-        self.show()
-        self.set_text(str, align)
-    def set_text(self, str, align=''):
-        for o in self.get_children():
-            o.destroy()
-        self.m_str = str
-        if align == 'center':
-            self.pack_start(gtk.HBox())
-        while self.m_str:
-            T, A, B = self.get_next_token()
-            if T == 'big' or T == 'err':
-                self.bigchar(A)
-            elif T == 'two':
-                self.twoline(A, B)
-            else:
-                assert T == 'one'
-                self.oneline(A)
-        if align == 'center':
-            self.pack_start(gtk.HBox())
-        self.show_all()
-    def get_next_token(self):
-        m_re1 = re.compile("([^\(]+)")
-        m_re2 = re.compile("\((\w*),\s*(\w*)\)")
-        m_re3 = re.compile("\((\w*)\)")
-        m1 = m_re1.match(self.m_str)
-        m2 = m_re2.match(self.m_str)
-        m3 = m_re3.match(self.m_str)
-        if m1:
-            self.m_str = self.m_str[len(m1.group()):]
-            return "big", m1.groups()[0], None
-        if m2:
-            self.m_str = self.m_str[len(m2.group()):]
-            return "two", m2.groups()[0], m2.groups()[1]
-        if m3:
-            self.m_str = self.m_str[len(m3.group()):]
-            return "one", m3.groups()[0], None
-        return "err"
-    def twoline(self, A, B):
-        vbox = gtk.VBox()
-        t1 = gtk.Label(A)
-        t1.set_name("ProgressionLabelNumber")
-        t1.show();vbox.pack_start(t1);
-        t1.set_alignment(0, 0);
-        t2 = gtk.Label(B)
-        t2.set_name("ProgressionLabelNumber")
-        t2.show();vbox.pack_start(t2);
-        t2.set_alignment(0, 0);
-        self.pack_start(vbox, False)
-    def oneline(self, A):
-        vbox = gtk.VBox()
-        t = gtk.Label(A)
-        t.set_name("ProgressionLabelNumber")
-        t.show();vbox.pack_start(t);
-        t.set_alignment(0, 0);
-        self.pack_start(vbox, False)
-    def bigchar(self, A):
-        t1 = gtk.Label(A)
-        t1.set_name("ProgressionNameLabel")
-        t1.show()
-        self.pack_start(t1, False)
-
 
 class AbstractQuestionNameTable(gtk.Table, cfg.ConfigUtils):
     """
@@ -168,7 +100,7 @@ class QuestionNameButtonTable(AbstractQuestionNameTable):
         b.set_data('cname', question.get_cname())
         b.set_sensitive(question['active'])
         if style == 'progression':
-            b.add(HarmonicProgressionLabel(question.get_name(), 'center'))
+            b.add(gu.HarmonicProgressionLabel(question.get_name(), 'center'))
         else:
             b.add(gtk.Label(question.get_name()))
         b.show_all()
@@ -210,7 +142,7 @@ class QuestionNameCheckButtonTable(AbstractQuestionNameTable):
         b.connect('toggled', self.on_checkbutton_toggled)
         b.set_data('cname', question.get_cname())
         if labelformat == 'progression':
-            b.add(HarmonicProgressionLabel(question.get_name(), 'center'))
+            b.add(gu.HarmonicProgressionLabel(question.get_name(), 'center'))
         elif labelformat == 'normal':
             b.add(gtk.Label(question.get_name()))
         else:
