@@ -1,10 +1,11 @@
-#!/usr/bin/env python
+#!/usr/bin/python2.3
+
 import sys
 sys.path.insert(0, ".")
 import soundcard
 
 #soundcard.initialise("/dev/sequencer", 0)
-soundcard.initialise("/dev/music", 0)
+soundcard.initialise_devicefile("/dev/music", 2)
 #soundcard.initialise("drvmidi -i d %s")
 
 t = soundcard.Track()
@@ -15,6 +16,9 @@ t.note(4, 9, 64, 100)
 t.notelen_time(4)
 t.note(4, 9, 67, 100)
 t.notelen_time(4)
+
+print "Playing three short sounds"
+
 soundcard.synth.play_track(t)
 
 import sys
